@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.19_90'; # TRIAL VERSION
+our $VERSION = '1.19_91'; # TRIAL VERSION
 
 sub new {
 	my ( $class, %args ) = @_;
@@ -261,7 +261,7 @@ Pod::Spell - a formatter for spellchecking Pod
 
 =head1 VERSION
 
-version 1.19_90
+version 1.19_91
 
 =head1 SYNOPSIS
 
@@ -479,7 +479,7 @@ L<perlpod|perlpod>, L<perlpodspec>
 
 =head1 CONTRIBUTORS
 
-=for stopwords David Golden Kent Fredric Mohammad S Anwar Olivier Mengué
+=for stopwords David Golden Kent Fredric Mohammad S Anwar Olivier Mengué Paulo Custodio
 
 =over 4
 
@@ -499,6 +499,10 @@ Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 Olivier Mengué <dolmen@cpan.org>
 
+=item *
+
+Paulo Custodio <pauloscustodio@gmail.com>
+
 =back
 
 =head1 AUTHORS
