@@ -2,24 +2,39 @@ package Pod::Wordlist;
 use strict;
 use warnings;
 use Lingua::EN::Inflect 'PL';
-use File::ShareDir::ProjectDistDir 1.000
-	dist_file => defaults => { pathtiny => 1 , strict => 1 };
 
 use Class::Tiny {
-    wordlist  => \&_copy_wordlist,
-    _is_debug => 0,
-    no_wide_chars => 0,
+	wordlist  => \&_copy_wordlist,
+	_is_debug => 0,
+	no_wide_chars => 0,
 };
 
-use constant MAXWORDLENGTH => 50; ## no critic ( ProhibitConstantPragma )
+use Path::Tiny qw( path );
+use constant {
 
-our $VERSION = '1.19_90'; # TRIAL VERSION
+	MAXWORDLENGTH => 50,
+
+	_DIST_DIR => do {
+		my $dir;
+		if ( -e __FILE__ ) {
+			my $local_dir = path(__FILE__)->parent->parent->parent->child('share/dist/Pod-Spell');
+			$dir = $local_dir->absolute if -e $local_dir;
+		}
+		if ( not defined $dir ) {
+			require File::ShareDir;
+			$dir = File::ShareDir::dist_dir('Pod-Spell');
+		}
+		"$dir"
+	},
+};
+
+our $VERSION = '1.19_91'; # TRIAL VERSION
 
 our %Wordlist; ## no critic ( Variables::ProhibitPackageVars )
 
 sub _copy_wordlist { return { %Wordlist } }
 
-foreach ( dist_file('Pod-Spell', 'wordlist')->lines_utf8({ chomp => 1 })) {
+foreach ( path(_DIST_DIR,'wordlist')->lines_utf8({ chomp => 1 })) {
 	$Wordlist{$_} = 1;
 	$Wordlist{PL($_)} = 1;
 }
@@ -116,19 +131,19 @@ sub _strip_a_word {
 	my ($self, $word) = @_;
 	my $remainder;
 
+	# try word as-is, including possible hyphenation vs stoplist
+	if ($self->is_stopword($word) ) {
+		$remainder = '';
+	}
 	# internal period could be abbreviations, so check with
 	# trailing period restored and drop or keep on that basis
-	if ( /\./ ) {
+	elsif ( index($word, '.') >= 0 ) {
 		my $abbr = "$word.";
 		$remainder = $self->is_stopword($abbr) ? '' : $abbr;
 	}
-	# try word as-is, including possible hyphenation vs stoplist
-	elsif ($self->is_stopword($word) ) {
-		$remainder = '';
-	}
 	# check individual parts of hyphenated word, keep whatever isn't a
 	# stopword as individual words
-	elsif ( $word =~ /-/ ) {
+	elsif ( index($word, '-') >= 0 ) {
 		my @keep;
 		for my $part ( split /-/, $word ) {
 			push @keep, $part if ! $self->is_stopword( $part );
@@ -160,7 +175,7 @@ Pod::Wordlist - English words that come up in Perl documentation
 
 =head1 VERSION
 
-version 1.19_90
+version 1.19_91
 
 =head1 DESCRIPTION
 
